<?php

namespace FiloBlu\Flow\Model\Parser;

use Exception;

/**
 * Class Csv
 * @package FiloBlu\Flow\Model\Parser
 */
class Csv extends AbstractParser
{
    /**
     * @param $resource string absolute path of the the csv file
     * @throws Exception
     */
    public function process($resource)
    {
        $channel = $this->getChannel();
        $count = 0;

        if (false === ($handle = @fopen($resource, 'rb'))) {
            throw new Exception("Unable to open {$resource}");
        }

        if ($this->hasBom($handle)) {
            $this->_logger->warning("$resource has BOM marker");
        }

        while (($data = fgetcsv($handle, 0, $this->separator, $this->delimiter)) !== false) {

            $count++;

            if ($count === 1) {

                if (!empty($this->header)) {
                    //throw new Exception("Header is already set but it should not: values => " . var_export($this->header, true));
                    $this->header = [];
                }

                foreach ($data as $header) {
                    // Remove BOM Marker
                    $header = trim($header, b"\xEF\xBB\xBF");
                    $this->header[] = trim(strtolower(trim($header)));
                }
            }

            if ($count <= $this->linesToSkip) {
                continue;
            }

            try {

                array_walk($data, static function (&$value, $key) {
                    $value = trim($value);
                    if ($value === null || ctype_space($value)) {
                        $value = null;
                    }
                });
                $this->parse($data);
            } catch (Exception $e) {
                throw new Exception($e->getMessage() . ' at row' . $count);
            }

        }

        fclose($handle);

        if (null !== $channel && method_exists($channel, 'commitData')) {
            $channel->commitData();
        }
    }


    /**
     * @param $file
     * @return false
     */
    public function hasBom($file)
    {
        $bom = fread($file, 3);
        fseek($file, 0);

        if ($bom !== b"\xEF\xBB\xBF") {
            return false;
        }

        return true;
    }
}
